@@ -1,6 +1,4 @@
-# Core of Boruta.
-# Author: Miron B. Kursa, based on the idea & original code by Witold R. Rudnicki
-###############################################################################
+# Core of Boruta
 
 #' @export
 #' @rdname Boruta
@@ -10,7 +8,7 @@ Boruta<-function(x,...)
 #' Feature selection with the Boruta algorithm
 #'
 #' Boruta is an all relevant feature selection wrapper algorithm, capable of working with any classification method that output variable importance measure (VIM); by default, Boruta uses Random Forest.
-#' The method performs a top-down search for relevant features by comparing original attributes' importance with importance achievable at random, estimated using their permuted copies, and progressively elliminating irrelevant featurs to stabilise that test.
+#' The method performs a top-down search for relevant features by comparing original attributes' importance with importance achievable at random, estimated using their permuted copies, and progressively eliminating irrelevant features to stabilise that test.
 #' @rdname Boruta
 #' @method Boruta default
 #' @param x data frame of predictors.
@@ -26,7 +24,7 @@ Boruta<-function(x,...)
 #' You may increase it to resolve attributes left Tentative.
 #' @param holdHistory if set to \code{TRUE}, the full history of importance is stored and returned as the \code{ImpHistory} element of the result.
 #' Can be used to decrease a memory footprint of Boruta in case this side data is not used, especially when the number of attributes is huge; yet it disables plotting of such made \code{Boruta} objects and the use of the \code{\link{TentativeRoughFix}} function.
-#' @param doTrace verbosity level. 0 means no tracing, 1 means reporting decision about each attribute as soon as it is justified, 2 means same as 1, plus reporting each importance source run.
+#' @param doTrace verbosity level. 0 means no tracing, 1 means reporting decision about each attribute as soon as it is justified, 2 means the same as 1, plus reporting each importance source run, 3 means the same as 2, plus reporting of hits assigned to yet undecided attributes.
 #' @param ... additional parameters passed to \code{getImp}.
 #' @return An object of class \code{Boruta}, which is a list with the following components:
 #' \item{finalDecision}{a factor of three value: \code{Confirmed}, \code{Rejected} or \code{Tentative}, containing final result of feature selection.}
@@ -46,12 +44,9 @@ Boruta<-function(x,...)
 #' They are claimed Tentative.
 #' You may try to extend \code{maxRuns} or lower \code{pValue} to clarify them, but in some cases their importances do fluctuate too much for Boruta to converge.
 #' Instead, you can use \code{\link{TentativeRoughFix}} function, which will perform other, weaker test to make a final decision, or simply treat them as undecided in further analysis.
-#' @note Version 5.0 and 2.0 change some name conventions and thus may be incompatible with scripts written for earlier Boruta versions.
-#' Solutions of most problems of this kind should boil down to change of \code{ZScoreHistory} to \code{ImpHistory} in script source or Boruta object structure.
 #' @references Miron B. Kursa, Witold R. Rudnicki (2010). Feature Selection with the Boruta Package.
 #' \emph{Journal of Statistical Software, 36(11)}, p. 1-13.
 #' URL: \url{http://www.jstatsoft.org/v36/i11/}
-#' @author Miron B. Kursa, based on the idea & original code by Witold R. Rudnicki.
 #' @export
 #' @examples
 #' set.seed(777)
@@ -129,7 +124,7 @@ Boruta.default<-function(x,y,pValue=0.01,mcAdj=TRUE,maxRuns=100,doTrace=0,holdHi
   names(xSha)<-paste('shadow',1:nSha,sep="")
 
   #Notifying user of our progress
-  if(doTrace==2)
+  if(doTrace>1)
    message(sprintf(' %s. run of importance source...',runs))
 
   #Calling importance source; "..." can be used by the user to pass rf attributes (for instance ntree)
@@ -154,6 +149,14 @@ Boruta.default<-function(x,y,pValue=0.01,mcAdj=TRUE,maxRuns=100,doTrace=0,holdHi
  ##Assigns hits
  assignHits<-function(hitReg,curImp){
   curImp$imp>max(curImp$shaImp)->hits
+  if(doTrace>2){
+   uncMask<-decReg=="Tentative"
+   intHits<-sum(hits[uncMask])
+   if(intHits>0)
+    message(sprintf("Assigned hit to %s attribute%s out of %s undecided.",sum(hits[uncMask]),if(intHits==1) "" else "s",sum(uncMask)))
+   else
+    message("None of undecided attributes scored a hit.")
+  }
   hitReg[hits]<-hitReg[hits]+1
   return(hitReg)
  }
@@ -271,7 +274,6 @@ Boruta.formula<-function(formula,data=.GlobalEnv,...){
 #' @param x an object of a class Boruta.
 #' @param ... additional arguments passed to \code{\link{print}}.
 #' @return Invisible copy of \code{x}.
-#' @author Miron B. Kursa
 #' @export
 print.Boruta<-function(x,...){
  if(class(x)!='Boruta') stop("This is NOT a Boruta object!")
